@@ -1,6 +1,15 @@
 #include "squid.h"
 #include "AccessLogEntry.h"
+#include "HttpReply.h"
 #include "HttpRequest.h"
+#include "SquidConfig.h"
+#include "ssl/support.h"
+
+#if USE_SSL
+AccessLogEntry::SslDetails::SslDetails(): user(NULL), bumpMode(::Ssl::bumpEnd)
+{
+}
+#endif /* USE_SSL */
 
 void
 AccessLogEntry::getLogClientIp(char *buf, size_t bufsz) const
@@ -13,7 +22,7 @@ AccessLogEntry::getLogClientIp(char *buf, size_t bufsz) const
         if (tcpClient != NULL)
             tcpClient->remote.NtoA(buf, bufsz);
         else if (cache.caddr.IsNoAddr()) // e.g., ICAP OPTIONS lack client
-            strncpy(buf, "-", bufsz);
+            strncpy(buf, "-", 1);
         else
             cache.caddr.NtoA(buf, bufsz);
 }
