@@ -1,7 +1,5 @@
 
 /*
- * $Id$
- *
  * DEBUG: section 64    HTTP Range Header
  * AUTHOR: Alex Rousskov
  *
@@ -33,11 +31,13 @@
  *
  */
 
-#include "squid-old.h"
+#include "squid.h"
 #include "Store.h"
 #include "HttpHeaderRange.h"
 #include "client_side_request.h"
 #include "HttpReply.h"
+#include "HttpHeaderTools.h"
+#include "StrList.h"
 
 /*
  *    Currently only byte ranges are supported
@@ -57,7 +57,6 @@
  *    spec into type one above. (Canonization process).
  */
 
-
 /* local routines */
 #define known_spec(s) ((s) > HttpHdrRangeSpec::UnknownPosition)
 
@@ -104,7 +103,7 @@ HttpHdrRangeSpec::parseInit(const char *field, int flen)
             if (!httpHeaderParseOffset(field, &offset))
                 return false;
 
-            p++;
+            ++p;
 
             /* do we have last-pos ? */
             if (p - field < flen) {
@@ -132,11 +131,11 @@ void
 HttpHdrRangeSpec::packInto(Packer * packer) const
 {
     if (!known_spec(offset))	/* suffix */
-        packerPrintf(packer, "-%"PRId64,  length);
+        packerPrintf(packer, "-%" PRId64,  length);
     else if (!known_spec(length))		/* trailer */
-        packerPrintf(packer, "%"PRId64"-", offset);
+        packerPrintf(packer, "%" PRId64 "-", offset);
     else			/* range */
-        packerPrintf(packer, "%"PRId64"-%"PRId64,
+        packerPrintf(packer, "%" PRId64 "-%" PRId64,
                      offset, offset + length - 1);
 }
 
@@ -361,7 +360,6 @@ HttpHdrRange::merge (Vector<HttpHdrRangeSpec *> &basis)
            " specs, merged " << basis.size() - specs.size() << " specs");
 }
 
-
 void
 HttpHdrRange::getCanonizedSpecs (Vector<HttpHdrRangeSpec *> &copy)
 {
