@@ -2,27 +2,30 @@
  * DEBUG: section 93    ICAP (RFC 3507) Client
  */
 
-#include "squid-old.h"
+#include "squid.h"
+#include "acl/FilledChecklist.h"
+#include "adaptation/icap/Config.h"
+#include "adaptation/icap/Launcher.h"
+#include "adaptation/icap/Xaction.h"
+#include "base/TextException.h"
 #include "comm.h"
 #include "comm/Connection.h"
 #include "comm/ConnOpener.h"
 #include "comm/Write.h"
 #include "CommCalls.h"
-#include "HttpMsg.h"
-#include "adaptation/icap/Xaction.h"
-#include "adaptation/icap/Launcher.h"
-#include "adaptation/icap/Config.h"
-#include "base/TextException.h"
-#include "pconn.h"
-#include "HttpRequest.h"
-#include "HttpReply.h"
-#include "ipcache.h"
-#include "acl/FilledChecklist.h"
-#include "icap_log.h"
-#include "fde.h"
-#include "SquidTime.h"
 #include "err_detail_type.h"
-
+#include "fde.h"
+#include "forward.h"
+#include "globals.h"
+#include "HttpMsg.h"
+#include "HttpReply.h"
+#include "HttpRequest.h"
+#include "icap_log.h"
+#include "ipcache.h"
+#include "Mem.h"
+#include "pconn.h"
+#include "SquidConfig.h"
+#include "SquidTime.h"
 
 //CBDATA_NAMESPACED_CLASS_INIT(Adaptation::Icap, Xaction);
 
@@ -40,7 +43,9 @@ Adaptation::Icap::Xaction::Xaction(const char *aTypeName, Adaptation::Icap::Serv
         isRetriable(true),
         isRepeatable(true),
         ignoreLastWrite(false),
-        connector(NULL), reader(NULL), writer(NULL), closer(NULL)
+        connector(NULL), reader(NULL), writer(NULL), closer(NULL),
+        alep(new AccessLogEntry),
+        al(*alep)
 {
     debugs(93,3, typeName << " constructed, this=" << this <<
            " [icapx" << id << ']'); // we should not call virtual status() here
@@ -329,7 +334,6 @@ void Adaptation::Icap::Xaction::callException(const std::exception  &e)
     Adaptation::Initiate::callException(e);
 }
 
-
 void Adaptation::Icap::Xaction::callEnd()
 {
     if (doneWithIo()) {
@@ -533,16 +537,14 @@ void Adaptation::Icap::Xaction::tellQueryAborted()
     }
 }
 
-
 void Adaptation::Icap::Xaction::maybeLog()
 {
     if (IcapLogfileStatus == LOG_ENABLE) {
         ACLChecklist *checklist = new ACLFilledChecklist(::Config.accessList.icap, al.request, dash_str);
         if (!::Config.accessList.icap || checklist->fastCheck() == ACCESS_ALLOWED) {
             finalizeLogInfo();
-            icapLogLog(&al, checklist);
+            icapLogLog(alep, checklist);
         }
-        accessLogFreeMemory(&al);
         delete checklist;
     }
 }
