@@ -34,14 +34,15 @@
 #ifndef   SQUID_ERRORPAGE_H
 #define   SQUID_ERRORPAGE_H
 
-#include "squid.h"
-#if USE_AUTH
-#include "auth/UserRequest.h"
-#endif
 #include "cbdata.h"
 #include "comm/forward.h"
+#include "err_detail_type.h"
+#include "err_type.h"
+#include "HttpStatusCode.h"
 #include "ip/Address.h"
-#include "MemBuf.h"
+#include "SquidString.h"
+/* auth/UserRequest.h is empty unless USE_AUTH is defined */
+#include "auth/UserRequest.h"
 #if USE_SSL
 #include "ssl/ErrorDetail.h"
 #endif
@@ -89,17 +90,25 @@
  */
 
 class HttpReply;
+class HttpRequest;
 class MemBuf;
 
 /// \ingroup ErrorPageAPI
 class ErrorState
 {
 public:
+    ErrorState(err_type type, http_status, HttpRequest * request);
+    ErrorState(); // not implemented.
+    ~ErrorState();
+
     /**
      * Allocates and initializes an error response
      */
     HttpReply *BuildHttpReply(void);
 
+    /// set error type-specific detail code
+    void detailError(int dCode) {detailCode = dCode;}
+
 private:
     /**
      * Locates error page template to be used for this error
@@ -146,12 +155,12 @@ public:
     char *err_language;
     http_status httpStatus;
 #if USE_AUTH
-    AuthUserRequest::Pointer auth_user_request;
+    Auth::UserRequest::Pointer auth_user_request;
 #endif
     HttpRequest *request;
     char *url;
     int xerrno;
-    u_short port;
+    unsigned short port;
     String dnsError; ///< DNS lookup error message
     time_t ttl;
 
@@ -178,6 +187,9 @@ public:
 #if USE_SSL
     Ssl::ErrorDetail *detail;
 #endif
+    /// type-specific detail about the transaction error;
+    /// overwrites xerrno; overwritten by detail, if any.
+    int detailCode;
 private:
     CBDATA_CLASS2(ErrorState);
 };
@@ -191,10 +203,10 @@ private:
  \par Global effects:
  *            error_text[] - is modified
  */
-SQUIDCEXTERN void errorInitialize(void);
+void errorInitialize(void);
 
 /// \ingroup ErrorPageAPI
-SQUIDCEXTERN void errorClean(void);
+void errorClean(void);
 
 /**
  * \ingroup ErrorPageAPI
@@ -216,7 +228,7 @@ SQUIDCEXTERN void errorClean(void);
  \param clientConn  socket where page object is to be written
  \param err         This object is destroyed after use in this function.
  */
-SQUIDCEXTERN void errorSend(const Comm::ConnectionPointer &conn, ErrorState *err);
+void errorSend(const Comm::ConnectionPointer &conn, ErrorState *err);
 
 /**
  \ingroup ErrorPageAPI
@@ -234,21 +246,12 @@ SQUIDCEXTERN void errorSend(const Comm::ConnectionPointer &conn, ErrorState *err
  \param entry   ??
  \param err     This object is destroyed after use in this function.
  */
-SQUIDCEXTERN void errorAppendEntry(StoreEntry *entry, ErrorState *err);
+void errorAppendEntry(StoreEntry *entry, ErrorState *err);
 
 /// \ingroup ErrorPageAPI
-SQUIDCEXTERN void errorStateFree(ErrorState * err);
+err_type errorReservePageId(const char *page_name);
 
-/// \ingroup ErrorPageAPI
-SQUIDCEXTERN err_type errorReservePageId(const char *page_name);
-
-/**
- \ingroup ErrorPageAPI
- *
- * This function creates a ErrorState object.
- */
-SQUIDCEXTERN ErrorState *errorCon(err_type type, http_status, HttpRequest * request);
-SQUIDCEXTERN const char *errorPageName(int pageId); ///< error ID to string
+const char *errorPageName(int pageId); ///< error ID to string
 
 /**
  \ingroup ErrorPageAPI
@@ -259,7 +262,7 @@ SQUIDCEXTERN const char *errorPageName(int pageId); ///< error ID to string
 class TemplateFile
 {
 public:
-    TemplateFile(const char *name);
+    TemplateFile(const char *name, const err_type code);
     virtual ~TemplateFile() {}
 
     /// return true if the data loaded from disk without any problem
@@ -306,6 +309,7 @@ protected:
     bool wasLoaded; ///< True if the template data read from disk without any problem
     String errLanguage; ///< The error language of the template.
     String templateName; ///< The name of the template
+    err_type templateCode; ///< The internal code for this template.
 };
 
 /**
