@@ -1,10 +1,9 @@
 /*
- * $Id$
- *
  * DEBUG: section 47    Store Directory Routines
  */
 
 #include "squid.h"
+#include "cache_cf.h"
 #include "ConfigOption.h"
 #include "DiskIO/DiskIOModule.h"
 #include "DiskIO/DiskIOStrategy.h"
@@ -14,12 +13,21 @@
 #include "fs/rock/RockIoState.h"
 #include "fs/rock/RockIoRequests.h"
 #include "fs/rock/RockRebuild.h"
+#include "globals.h"
 #include "ipc/mem/Pages.h"
 #include "MemObject.h"
 #include "Parsing.h"
+#include "SquidConfig.h"
 #include "SquidMath.h"
+#include "tools.h"
+
+#include <cstdlib>
 #include <iomanip>
 
+#if HAVE_SYS_STAT_H
+#include <sys/stat.h>
+#endif
+
 const int64_t Rock::SwapDir::HeaderSize = 16*1024;
 
 Rock::SwapDir::SwapDir(): ::SwapDir("rock"), filePath(NULL), io(NULL), map(NULL)
@@ -152,19 +160,8 @@ Rock::SwapDir::create()
 
     debugs (47,3, HERE << "creating in " << path);
 
-    struct stat dir_sb;
-    if (::stat(path, &dir_sb) == 0) {
-        struct stat file_sb;
-        if (::stat(filePath, &file_sb) == 0) {
-            debugs (47, DBG_IMPORTANT, "Skipping existing Rock db: " << filePath);
-            return;
-        }
-        // else the db file is not there or is not accessible, and we will try
-        // to create it later below, generating a detailed error on failures.
-    } else { // path does not exist or is inaccessible
-        // If path exists but is not accessible, mkdir() below will fail, and
-        // the admin should see the error and act accordingly, so there is
-        // no need to distinguish ENOENT from other possible stat() errors.
+    struct stat swap_sb;
+    if (::stat(path, &swap_sb) < 0) {
         debugs (47, DBG_IMPORTANT, "Creating Rock db directory: " << path);
         const int res = mkdir(path, 0700);
         if (res != 0) {
@@ -174,7 +171,6 @@ Rock::SwapDir::create()
         }
     }
 
-    debugs (47, DBG_IMPORTANT, "Creating Rock db: " << filePath);
 #if SLOWLY_FILL_WITH_ZEROS
     char block[1024];
     Must(maxSize() % sizeof(block) == 0);
@@ -470,7 +466,6 @@ Rock::SwapDir::addEntry(const int filen, const DbCellHeader &header, const Store
     return false;
 }
 
-
 bool
 Rock::SwapDir::canStore(const StoreEntry &e, int64_t diskSpaceNeeded, int &load) const
 {
@@ -785,7 +780,6 @@ Rock::SwapDir::trackReferences(StoreEntry &e)
         repl->Add(repl, &e, &e.repl);
 }
 
-
 void
 Rock::SwapDir::ignoreReferences(StoreEntry &e)
 {
@@ -834,7 +828,6 @@ Rock::SwapDir::statfs(StoreEntry &e) const
 
 }
 
-
 namespace Rock
 {
 RunnerRegistrationEntry(rrAfterConfig, SwapDirRr);
