@@ -1,7 +1,3 @@
-/*
- * $Id$
- */
-
 #include "squid.h"
 #include "ssl/certificate_db.h"
 #if HAVE_ERRNO_H
@@ -56,7 +52,6 @@ void Ssl::Lock::lock()
 #endif
         throw std::runtime_error("Failed to open file " + filename);
 
-
 #if _SQUID_MSWIN_
     if (!LockFile(hFile, 0, 0, 1, 0))
 #else
@@ -108,38 +103,19 @@ Ssl::Locker::~Locker()
 Ssl::CertificateDb::Row::Row()
         :   width(cnlNumber)
 {
-    row = (char **)OPENSSL_malloc(sizeof(char *) * (width + 1));
+    row = new char *[width + 1];
     for (size_t i = 0; i < width + 1; ++i)
         row[i] = NULL;
 }
 
-Ssl::CertificateDb::Row::Row(char **aRow, size_t aWidth): width(aWidth)
-{
-    row = aRow;
-}
-
 Ssl::CertificateDb::Row::~Row()
 {
-    if (!row)
-        return;
-
-    void *max;
-    if ((max = (void *)row[width]) != NULL) {
-        // It is an openSSL allocated row. The TXT_DB_read function stores the
-        // index and row items one one memory segment. The row[width] points
-        // to the end of buffer. We have to check for items in the array which
-        // are not stored in this segment. These items should released.
+    if (row) {
         for (size_t i = 0; i < width + 1; ++i) {
-            if (((row[i] < (char *)row) || (row[i] > max)) && (row[i] != NULL))
-                OPENSSL_free(row[i]);
-        }
-    } else {
-        for (size_t i = 0; i < width + 1; ++i) {
-            if (row[i])
-                OPENSSL_free(row[i]);
+            delete[](row[i]);
         }
+        delete[](row);
     }
-    OPENSSL_free(row);
 }
 
 void Ssl::CertificateDb::Row::reset()
@@ -154,7 +130,7 @@ void Ssl::CertificateDb::Row::setValue(size_t cell, char const * value)
         free(row[cell]);
     }
     if (value) {
-        row[cell] = static_cast<char *>(OPENSSL_malloc(sizeof(char) * (strlen(value) + 1)));
+        row[cell] = static_cast<char *>(malloc(sizeof(char) * (strlen(value) + 1)));
         memcpy(row[cell], value, sizeof(char) * (strlen(value) + 1));
     } else
         row[cell] = NULL;
@@ -165,55 +141,6 @@ char ** Ssl::CertificateDb::Row::getRow()
     return row;
 }
 
-void Ssl::CertificateDb::sq_TXT_DB_delete(TXT_DB *db, const char **row)
-{
-    if (!db)
-        return;
-
-#if OPENSSL_VERSION_NUMBER >= 0x1000004fL
-    for (int i = 0; i < sk_OPENSSL_PSTRING_num(db->data); ++i) {
-        const char ** current_row = ((const char **)sk_OPENSSL_PSTRING_value(db->data, i));
-#else
-    for (int i = 0; i < sk_num(db->data); ++i) {
-        const char ** current_row = ((const char **)sk_value(db->data, i));
-#endif
-        if (current_row == row) {
-            sq_TXT_DB_delete_row(db, i);
-            return;
-        }
-    }
-}
-
-#define countof(arr) (sizeof(arr)/sizeof(*arr))
-void Ssl::CertificateDb::sq_TXT_DB_delete_row(TXT_DB *db, int idx)
-{
-    char **rrow;
-#if OPENSSL_VERSION_NUMBER >= 0x1000004fL
-    rrow = (char **)sk_OPENSSL_PSTRING_delete(db->data, idx);
-#else
-    rrow = (char **)sk_delete(db->data, idx);
-#endif
-
-    if (!rrow)
-        return;
-
-    Row row(rrow, cnlNumber); // row wrapper used to free the rrow
-
-    const Columns db_indexes[]={cnlSerial, cnlName};
-    for (unsigned int i = 0; i < countof(db_indexes); ++i) {
-        void *data = NULL;
-#if OPENSSL_VERSION_NUMBER >= 0x1000004fL
-        if (LHASH_OF(OPENSSL_STRING) *fieldIndex =  db->index[db_indexes[i]])
-            data = lh_OPENSSL_STRING_delete(fieldIndex, rrow);
-#else
-        if (LHASH *fieldIndex = db->index[db_indexes[i]])
-            data = lh_delete(fieldIndex, rrow);
-#endif
-        if (data)
-            assert(data == rrow);
-    }
-}
-
 unsigned long Ssl::CertificateDb::index_serial_hash(const char **a)
 {
     const char *n = a[Ssl::CertificateDb::cnlSerial];
@@ -240,14 +167,12 @@ int Ssl::CertificateDb::index_name_cmp(const char **a, const char **b)
     return(strcmp(a[Ssl::CertificateDb::cnlName], b[CertificateDb::cnlName]));
 }
 
-const std::string Ssl::CertificateDb::serial_file("serial");
 const std::string Ssl::CertificateDb::db_file("index.txt");
 const std::string Ssl::CertificateDb::cert_dir("certs");
 const std::string Ssl::CertificateDb::size_file("size");
 
 Ssl::CertificateDb::CertificateDb(std::string const & aDb_path, size_t aMax_db_size, size_t aFs_block_size)
         :  db_path(aDb_path),
-        serial_full(aDb_path + "/" + serial_file),
         db_full(aDb_path + "/" + db_file),
         cert_full(aDb_path + "/" + cert_dir),
         size_full(aDb_path + "/" + size_file),
@@ -255,7 +180,6 @@ Ssl::CertificateDb::CertificateDb(std::string const & aDb_path, size_t aMax_db_s
         max_db_size(aMax_db_size),
         fs_block_size(aFs_block_size),
         dbLock(db_full),
-        dbSerialLock(serial_full),
         enabled_disk_store(true)
 {
     if (db_path.empty() && !max_db_size)
@@ -271,7 +195,21 @@ bool Ssl::CertificateDb::find(std::string const & host_name, Ssl::X509_Pointer &
     return pure_find(host_name, cert, pkey);
 }
 
-bool Ssl::CertificateDb::addCertAndPrivateKey(Ssl::X509_Pointer & cert, Ssl::EVP_PKEY_Pointer & pkey)
+bool Ssl::CertificateDb::purgeCert(std::string const & key)
+{
+    const Locker locker(dbLock, Here);
+    load();
+    if (!db)
+        return false;
+
+    if (!deleteByHostname(key))
+        return false;
+
+    save();
+    return true;
+}
+
+bool Ssl::CertificateDb::addCertAndPrivateKey(Ssl::X509_Pointer & cert, Ssl::EVP_PKEY_Pointer & pkey, std::string const & useName)
 {
     const Locker locker(dbLock, Here);
     load();
@@ -287,24 +225,15 @@ bool Ssl::CertificateDb::addCertAndPrivateKey(Ssl::X509_Pointer & cert, Ssl::EVP
     }
     row.setValue(cnlSerial, serial_string.c_str());
     char ** rrow = TXT_DB_get_by_index(db.get(), cnlSerial, row.getRow());
-    if (rrow != NULL) {
-        // TODO: check if the stored row is valid.
+    // We are creating certificates with unique serial numbers. If the serial
+    // number is found in the database, the same certificate is already stored.
+    if (rrow != NULL)
         return true;
-    }
 
     {
         TidyPointer<char, tidyFree> subject(X509_NAME_oneline(X509_get_subject_name(cert.get()), NULL, 0));
-        Ssl::X509_Pointer findCert;
-        Ssl::EVP_PKEY_Pointer findPkey;
-        if (pure_find(subject.get(), findCert, findPkey)) {
-            // Replace with database certificate
-            cert.reset(findCert.release());
-            pkey.reset(findPkey.release());
+        if (pure_find(useName.empty() ? subject.get() : useName, cert, pkey))
             return true;
-        }
-        // pure_find may fail because the entry is expired, or because the
-        // certs file is corrupted. Remove any entry with given hostname
-        deleteByHostname(subject.get());
     }
 
     // check db size while trying to minimize calls to size()
@@ -314,10 +243,8 @@ bool Ssl::CertificateDb::addCertAndPrivateKey(Ssl::X509_Pointer & cert, Ssl::EVP
 
         // there are no more invalid ones, but there must be valid certificates
         do {
-            if (!deleteOldestCertificate()) {
-                save(); // Some entries may have been removed. Update the index file.
+            if (!deleteOldestCertificate())
                 return false; // errors prevented us from freeing enough space
-            }
         } while (size() > max_db_size);
         break;
     }
@@ -326,113 +253,40 @@ bool Ssl::CertificateDb::addCertAndPrivateKey(Ssl::X509_Pointer & cert, Ssl::EVP
     ASN1_UTCTIME * tm = X509_get_notAfter(cert.get());
     row.setValue(cnlExp_date, std::string(reinterpret_cast<char *>(tm->data), tm->length).c_str());
     row.setValue(cnlFile, "unknown");
-    {
+    if (!useName.empty())
+        row.setValue(cnlName, useName.c_str());
+    else {
         TidyPointer<char, tidyFree> subject(X509_NAME_oneline(X509_get_subject_name(cert.get()), NULL, 0));
         row.setValue(cnlName, subject.get());
     }
 
-    if (!TXT_DB_insert(db.get(), row.getRow())) {
-        // failed to add index (???) but we may have already modified
-        // the database so save before exit
-        save();
+    if (!TXT_DB_insert(db.get(), row.getRow()))
         return false;
-    }
-    rrow = row.getRow();
-    row.reset();
 
+    row.reset();
     std::string filename(cert_full + "/" + serial_string + ".pem");
-    if (!writeCertAndPrivateKeyToFile(cert, pkey, filename.c_str())) {
-        //remove row from txt_db and save
-        sq_TXT_DB_delete(db.get(), (const char **)rrow);
-        save();
+    if (!writeCertAndPrivateKeyToFile(cert, pkey, filename.c_str()))
         return false;
-    }
     addSize(filename);
 
     save();
     return true;
 }
 
-BIGNUM * Ssl::CertificateDb::getCurrentSerialNumber()
-{
-    const Locker locker(dbSerialLock, Here);
-    // load serial number from file.
-    Ssl::BIO_Pointer file(BIO_new(BIO_s_file()));
-    if (!file)
-        return NULL;
-
-    if (BIO_rw_filename(file.get(), const_cast<char *>(serial_full.c_str())) <= 0)
-        return NULL;
-
-    Ssl::ASN1_INT_Pointer serial_ai(ASN1_INTEGER_new());
-    if (!serial_ai)
-        return NULL;
-
-    char buffer[1024];
-    if (!a2i_ASN1_INTEGER(file.get(), serial_ai.get(), buffer, sizeof(buffer)))
-        return NULL;
-
-    Ssl::BIGNUM_Pointer serial(ASN1_INTEGER_to_BN(serial_ai.get(), NULL));
-
-    if (!serial)
-        return NULL;
-
-    // increase serial number.
-    Ssl::BIGNUM_Pointer increased_serial(BN_dup(serial.get()));
-    if (!increased_serial)
-        return NULL;
-
-    BN_add_word(increased_serial.get(), 1);
-
-    // save increased serial number.
-    if (BIO_seek(file.get(), 0))
-        return NULL;
-
-    Ssl::ASN1_INT_Pointer increased_serial_ai(BN_to_ASN1_INTEGER(increased_serial.get(), NULL));
-    if (!increased_serial_ai)
-        return NULL;
-
-    i2a_ASN1_INTEGER(file.get(), increased_serial_ai.get());
-    BIO_puts(file.get(),"\n");
-
-    return serial.release();
-}
-
-void Ssl::CertificateDb::create(std::string const & db_path, int serial)
+void Ssl::CertificateDb::create(std::string const & db_path)
 {
     if (db_path == "")
         throw std::runtime_error("Path to db is empty");
-    std::string serial_full(db_path + "/" + serial_file);
     std::string db_full(db_path + "/" + db_file);
     std::string cert_full(db_path + "/" + cert_dir);
     std::string size_full(db_path + "/" + size_file);
 
-#if _SQUID_MSWIN_
-    if (mkdir(db_path.c_str()))
-#else
     if (mkdir(db_path.c_str(), 0777))
-#endif
         throw std::runtime_error("Cannot create " + db_path);
 
-#if _SQUID_MSWIN_
-    if (mkdir(cert_full.c_str()))
-#else
     if (mkdir(cert_full.c_str(), 0777))
-#endif
         throw std::runtime_error("Cannot create " + cert_full);
 
-    Ssl::ASN1_INT_Pointer i(ASN1_INTEGER_new());
-    ASN1_INTEGER_set(i.get(), serial);
-
-    Ssl::BIO_Pointer file(BIO_new(BIO_s_file()));
-    if (!file)
-        throw std::runtime_error("SSL error");
-
-    if (BIO_write_filename(file.get(), const_cast<char *>(serial_full.c_str())) <= 0)
-        throw std::runtime_error("Cannot open " + cert_full + " to open");
-
-    i2a_ASN1_INTEGER(file.get(), i.get());
-
     std::ofstream size(size_full.c_str());
     if (size)
         size << 0;
@@ -449,17 +303,6 @@ void Ssl::CertificateDb::check(std::string const & db_path, size_t max_db_size)
     db.load();
 }
 
-std::string Ssl::CertificateDb::getSNString() const
-{
-    const Locker locker(dbSerialLock, Here);
-    std::ifstream file(serial_full.c_str());
-    if (!file)
-        return "";
-    std::string serial;
-    file >> serial;
-    return serial;
-}
-
 bool Ssl::CertificateDb::pure_find(std::string const & host_name, Ssl::X509_Pointer & cert, Ssl::EVP_PKEY_Pointer & pkey)
 {
     if (!db)
@@ -472,8 +315,10 @@ bool Ssl::CertificateDb::pure_find(std::string const & host_name, Ssl::X509_Poin
     if (rrow == NULL)
         return false;
 
-    if (!sslDateIsInTheFuture(rrow[cnlExp_date]))
+    if (!sslDateIsInTheFuture(rrow[cnlExp_date])) {
+        deleteByHostname(rrow[cnlName]);
         return false;
+    }
 
     // read cert and pkey from file.
     std::string filename(cert_full + "/" + rrow[cnlSerial] + ".pem");
@@ -573,10 +418,26 @@ void Ssl::CertificateDb::save()
 }
 
 // Normally defined in defines.h file
+#define countof(arr) (sizeof(arr)/sizeof(*arr))
 void Ssl::CertificateDb::deleteRow(const char **row, int rowIndex)
 {
     const std::string filename(cert_full + "/" + row[cnlSerial] + ".pem");
-    sq_TXT_DB_delete_row(db.get(), rowIndex);
+#if OPENSSL_VERSION_NUMBER >= 0x1000004fL
+    sk_OPENSSL_PSTRING_delete(db.get()->data, rowIndex);
+#else
+    sk_delete(db.get()->data, rowIndex);
+#endif
+
+    const Columns db_indexes[]={cnlSerial, cnlName};
+    for (unsigned int i = 0; i < countof(db_indexes); ++i) {
+#if OPENSSL_VERSION_NUMBER >= 0x1000004fL
+        if (LHASH_OF(OPENSSL_STRING) *fieldIndex =  db.get()->index[db_indexes[i]])
+            lh_OPENSSL_STRING_delete(fieldIndex, (char **)row);
+#else
+        if (LHASH *fieldIndex = db.get()->index[db_indexes[i]])
+            lh_delete(fieldIndex, row);
+#endif
+    }
 
     subSize(filename);
     int ret = remove(filename.c_str());
