@@ -119,7 +119,6 @@ extern "C" {
 }
 #endif
 
-
 #ifndef DEFAULT_CACHEMGR_CONFIG
 #define DEFAULT_CACHEMGR_CONFIG "/etc/squid/cachemgr.conf"
 #endif
@@ -325,7 +324,6 @@ auth_html(const char *host, int port, const char *user_name)
 
     printf("<TABLE BORDER=\"0\" CELLPADDING=\"10\" CELLSPACING=\"1\">\n");
 
-
     if (fp != NULL) {
         int servers = 0;
         char config_line[BUFSIZ];
@@ -596,15 +594,12 @@ munge_action_line(const char *_buf, cachemgr_request * req)
     if ((p = strchr(x, '\n')))
         *p = '\0';
     action = xstrtok(&x, '\t');
-    if (!action) {
-        xfree(buf);
-        return "";
-    }
     description = xstrtok(&x, '\t');
     if (!description)
         description = action;
+    if (!action)
+        return "";
     snprintf(html, sizeof(html), " <a href=\"%s\">%s</a>", menu_url(req, action), description);
-    xfree(buf);
     return html;
 }
 
@@ -833,7 +828,7 @@ process_request(cachemgr_request * req)
     }
 
     if (!check_target_acl(req->hostname, req->port)) {
-        snprintf(buf, sizeof(buf), "target %s:%d not allowed in cachemgr.conf\n", req->hostname, req->port);
+        snprintf(buf, 1024, "target %s:%d not allowed in cachemgr.conf\n", req->hostname, req->port);
         error_html(buf);
         return 1;
     }
@@ -845,7 +840,7 @@ process_request(cachemgr_request * req)
     } else if ((S = req->hostname))
         (void) 0;
     else {
-        snprintf(buf, sizeof(buf), "Unknown host: %s\n", req->hostname);
+        snprintf(buf, 1024, "Unknown host: %s\n", req->hostname);
         error_html(buf);
         return 1;
     }
@@ -859,19 +854,17 @@ process_request(cachemgr_request * req)
 #else
     if ((s = socket(PF_INET, SOCK_STREAM, 0)) < 0) {
 #endif
-        snprintf(buf, sizeof(buf), "socket: %s\n", xstrerror());
+        snprintf(buf, 1024, "socket: %s\n", xstrerror());
         error_html(buf);
-        S.FreeAddrInfo(AI);
         return 1;
     }
 
     if (connect(s, AI->ai_addr, AI->ai_addrlen) < 0) {
-        snprintf(buf, sizeof(buf), "connect %s: %s\n",
+        snprintf(buf, 1024, "connect %s: %s\n",
                  S.ToURL(ipbuf,MAX_IPSTRLEN),
                  xstrerror());
         error_html(buf);
         S.FreeAddrInfo(AI);
-        close(s);
         return 1;
     }
 
@@ -959,6 +952,8 @@ static char *
 read_post_request(void)
 {
     char *s;
+    char *buf;
+    int len;
 
     if ((s = getenv("REQUEST_METHOD")) == NULL)
         return NULL;
@@ -969,34 +964,15 @@ read_post_request(void)
     if ((s = getenv("CONTENT_LENGTH")) == NULL)
         return NULL;
 
-    if (*s == '-') // negative length content huh?
+    if ((len = atoi(s)) <= 0)
         return NULL;
 
-    uint64_t len;
+    buf = (char *)xmalloc(len + 1);
 
-    char *endptr = s+ strlen(s);
-    if ((len = strtoll(s, &endptr, 10)) <= 0)
+    if (fread(buf, len, 1, stdin) == 0)
         return NULL;
 
-    // limit the input to something reasonable.
-    // 4KB should be enough for the GET/POST data length, but may be extended.
-    size_t bufLen = (len < 4096 ? len : 4095);
-    char *buf = (char *)xmalloc(bufLen + 1);
-
-    size_t readLen = fread(buf, 1, bufLen, stdin);
-    if (readLen == 0) {
-        xfree(buf);
-        return NULL;
-    }
-    buf[readLen] = '\0';
-    len -= readLen;
-
-    // purge the remainder of the request entity
-    while (len > 0 && readLen) {
-        char temp[65535];
-        readLen = fread(temp, 1, 65535, stdin);
-        len -= readLen;
-    }
+    buf[len] = '\0';
 
     return buf;
 }
@@ -1090,7 +1066,6 @@ read_request(void)
     return req;
 }
 
-
 /* Routines to support authentication */
 
 /*
@@ -1143,49 +1118,37 @@ decode_pub_auth(cachemgr_request * req)
     debug("cmgr: length ok\n");
 
     /* parse ( a lot of memory leaks, but that is cachemgr style :) */
-    if ((host_name = strtok(buf, "|")) == NULL) {
-        xfree(buf);
+    if ((host_name = strtok(buf, "|")) == NULL)
         return;
-    }
 
     debug("cmgr: decoded host: '%s'\n", host_name);
 
-    if ((time_str = strtok(NULL, "|")) == NULL) {
-        xfree(buf);
+    if ((time_str = strtok(NULL, "|")) == NULL)
         return;
-    }
 
     debug("cmgr: decoded time: '%s' (now: %d)\n", time_str, (int) now);
 
-    if ((user_name = strtok(NULL, "|")) == NULL) {
-        xfree(buf);
+    if ((user_name = strtok(NULL, "|")) == NULL)
         return;
-    }
 
     debug("cmgr: decoded uname: '%s'\n", user_name);
 
-    if ((passwd = strtok(NULL, "|")) == NULL) {
-        xfree(buf);
+    if ((passwd = strtok(NULL, "|")) == NULL)
         return;
-    }
 
     debug("cmgr: decoded passwd: '%s'\n", passwd);
 
     /* verify freshness and validity */
-    if (atoi(time_str) + passwd_ttl < now) {
-        xfree(buf);
+    if (atoi(time_str) + passwd_ttl < now)
         return;
-    }
 
-    if (strcasecmp(host_name, req->hostname)) {
-        xfree(buf);
+    if (strcasecmp(host_name, req->hostname))
         return;
-    }
 
     debug("cmgr: verified auth. info.\n");
 
     /* ok, accept */
-    safe_free(req->user_name);
+    xfree(req->user_name);
 
     req->user_name = xstrdup(user_name);
 
@@ -1227,7 +1190,6 @@ make_auth_header(const cachemgr_request * req)
 
     snprintf(&buf[stringLength], sizeof(buf) - stringLength, "Proxy-Authorization: Basic %s\r\n", str64);
 
-    xfree(str64);
     return buf;
 }
 
