@@ -1,8 +1,5 @@
 #include "squid.h"
 
-//
-// $Id$
-//
 // Author:  Jens-S. V?ckler <voeckler@rvs.uni-hannover.de>
 //
 // File:    conffile.cc
@@ -48,7 +45,6 @@
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
-#include <fstream>
 
 int
 readConfigFile( CacheDirVector& cachedir, const char* fn, FILE* debug )
@@ -62,8 +58,8 @@ readConfigFile( CacheDirVector& cachedir, const char* fn, FILE* debug )
 
     // try to open file
     if ( debug ) fprintf( debug, "# trying to open %s\n", fn ? fn : "(null)" );
-    std::ifstream cfgin(fn);
-    if (!cfgin) {
+    FILE* in = fopen( fn, "r" );
+    if ( in == NULL ) {
         fprintf( stderr, "fopen %s: %s\n", fn, strerror(errno) );
         return -1;
     }
@@ -85,7 +81,7 @@ readConfigFile( CacheDirVector& cachedir, const char* fn, FILE* debug )
     regmatch_t subs[8];
     char *s, line[1024];
     CacheDir cd;
-    while ( cfgin.getline( line, sizeof(line)) ) {
+    while ( fgets( line, sizeof(line), in ) ) {
         // FIXME: overly long lines
 
         // terminate line at start of comment
@@ -103,7 +99,7 @@ readConfigFile( CacheDirVector& cachedir, const char* fn, FILE* debug )
                 fprintf( stderr, "while matching \"%s\" against %s%s\n",
                          expression, line, buffer );
                 regfree(&rexp);
-                cfgin.close();
+                fclose(in);
                 return -1;
             }
         } else {
@@ -180,7 +176,7 @@ readConfigFile( CacheDirVector& cachedir, const char* fn, FILE* debug )
         }
     }
 
-    cfgin.close();
+    fclose(in);
     regfree(&rexp);
     return cachedir.size();
 }
