@@ -1,6 +1,3 @@
-//
-// $Id$
-//
 // Author:  Jens-S. V?ckler <voeckler@rvs.uni-hannover.de>
 //
 // File:    purge.cc
@@ -98,16 +95,12 @@
 #endif
 
 #include "squid.h"
-// for xstrdup
 #include "util.h"
 
-//#include <assert.h>
 #include <stdarg.h>
 #include <stdio.h>
 #include <dirent.h>
-//#include <ctype.h>
 #include <string.h>
-//#include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/wait.h>
 #include <fcntl.h>
@@ -122,10 +115,9 @@
 #endif
 
 #include <netinet/in.h>
-#include <netinet/tcp.h>  // TCP_NODELAY
+#include <netinet/tcp.h>
 #include <arpa/inet.h>
-#include <netdb.h>        // gethostbyname()
-//#include <regex.h>    //comes via compat.h
+#include <netdb.h>
 
 #include "convert.hh"
 #include "socket.hh"
@@ -154,7 +146,6 @@ static bool verbose  = false;
 static bool envelope = false;
 static bool no_fork  = false;
 static const char* programname = 0;
-static const char* RCS_ID = "$Id$";
 
 // ----------------------------------------------------------------------
 
@@ -268,7 +259,7 @@ log_extended( const char* fn, int code, long size, const SquidMetaList* meta )
 
     if ( meta && (findings = meta->search( STORE_META_KEY_MD5 )) ) {
         unsigned char* s = (unsigned char*) findings->data;
-        for ( int j=0; j<16; j++, s++ ) {
+        for ( int j=0; j<16; ++j, ++s ) {
             md5[j*2+0] = hexdigit[ *s >> 4 ];
             md5[j*2+1] = hexdigit[ *s & 15 ];
         }
@@ -498,8 +489,7 @@ filelevel( const char* directory, const REList* list )
     if ( ::iamalive ) {
         static char alivelist[4][3] = { "\\\b", "|\b", "/\b", "-\b" };
         static unsigned short alivecount = 0;
-        const int write_success = write(STDOUT_FILENO, alivelist[alivecount++ & 3], 2);
-        assert(write_success == 2);
+        assert( write( STDOUT_FILENO, alivelist[alivecount++ & 3], 2 ) == 2 );
     }
 
     bool flag = true;
@@ -580,9 +570,9 @@ void
 helpMe( void )
 // purpuse: write help message and exit
 {
-    printf( "\n%s\nUsage:\t%s\t[-a] [-c cf] [-d l] [-(f|F) fn | -(e|E) re] "
+    printf( "\nUsage:\t%s\t[-a] [-c cf] [-d l] [-(f|F) fn | -(e|E) re] "
             "[-p h[:p]]\n\t\t[-P #] [-s] [-v] [-C dir [-H]] [-n]\n\n",
-            ::RCS_ID, ::programname );
+            ::programname );
     printf(
         " -a\tdisplay a little rotating thingy to indicate that I am alive (tty only).\n"
         " -c c\tsquid.conf location, default \"%s\".\n"
@@ -637,15 +627,13 @@ parseCommandline( int argc, char* argv[], REList*& head,
         case 'C':
             if ( optarg && *optarg ) {
                 if ( copydir ) xfree( (void*) copydir );
-                copydir = xstrdup(optarg);
-                assert(copydir);
+                assert( (copydir = xstrdup(optarg)) );
             }
             break;
         case 'c':
             if ( optarg && *optarg ) {
-                if ( *conffile ) xfree((void*) conffile);
-                conffile = xstrdup(optarg);
-                assert(conffile);
+                if ( *conffile ) xfree((void*) conffile );
+                assert( (conffile = xstrdup(optarg)) );
             }
             break;
 
@@ -765,8 +753,8 @@ parseCommandline( int argc, char* argv[], REList*& head,
 
     // show results
     if ( showme ) {
-        printf( "#\n# Currently active values for %s:\n# %s\n",
-                ::programname, ::RCS_ID );
+        printf( "#\n# Currently active values for %s:\n",
+                ::programname);
         printf( "# Debug level       : " );
         if ( ::debugFlag ) printf( "%#6.4x", ::debugFlag );
         else printf( "production level" ); // printf omits 0x prefix for 0!
